@@ -16,7 +16,7 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
-__version__ = "2.0.155"
+__version__ = "2.0.157"
 __license__ = "GNU Lesser General Public License v3.0 (LGPL-3.0)"
 __copyright__ = "Copyright (C) 2017-present Dan <https://github.com/delivrance>"
 
@@ -35,8 +35,36 @@ class ContinuePropagation(StopAsyncIteration):
     pass
 
 
-from . import raw, types, filters, handlers, emoji, enums
-from .client import Client
-from .sync import idle, compose
+crypto_executor = ThreadPoolExecutor(1, thread_name_prefix="CryptoWorker")
 
-crypto_executor = ThreadPoolExecutor(1, thread_name_prefix="CryptoWorker")
\ No newline at end of file
+import asyncio as _asyncio
+from contextlib import suppress
+
+from . import enums, errors, filters, handlers, raw, types
+from .client import Client
+from .methods.utilities.compose import compose
+from .methods.utilities.idle import idle
+
+with suppress(ImportError):
+    import uvloop as _uvloop
+
+    _asyncio.set_event_loop_policy(_uvloop.EventLoopPolicy())
+
+
+
+
+__all__ = [
+    "Client",
+    "ContinuePropagation",
+    "StopPropagation",
+    "StopTransmission",
+    "compose",
+    "crypto_executor",
+    "enums",
+    "errors",
+    "filters",
+    "handlers",
+    "idle",
+    "raw",
+    "types",
+]
