@@ -26,6 +26,7 @@ from .invite_links import InviteLinks
 from .messages import Messages
 from .password import Password
 from .premium import Premium
+from .pyromod import Pyromod
 from .users import Users
 from .stories import Stories
 from .stickers import Stickers
@@ -46,6 +47,7 @@ class Methods(
     Decorators,
     Stickers,
     Utilities,
+    Pyromod,
     InviteLinks,
 ):
     pass
