@@ -16,15 +16,17 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
-from datetime import datetime
-from typing import Union, List, Optional, AsyncGenerator, BinaryIO
+from __future__ import annotations
+
+from typing import BinaryIO, Union, Optional, List
 
 import pyrogram
-from pyrogram import raw, enums
-from pyrogram import types
-from pyrogram import utils
-from ..object import Object
+from pyrogram import enums, raw, types, utils, filters
+from pyrogram.types.object import Object
+from pyrogram.types import ListenerTypes
 
+from collections.abc import AsyncGenerator
+from datetime import datetime
 
 class Chat(Object):
     """A chat.
@@ -36,14 +38,11 @@ class Chat(Object):
         type (:obj:`~pyrogram.enums.ChatType`):
             Type of chat.
 
-        is_forum (``bool``, *optional*):
-            True, if the supergroup chat is a forum
-
         is_verified (``bool``, *optional*):
             True, if this chat has been verified by Telegram. Supergroups, channels and bots only.
 
         is_participants_hidden (``bool``, *optional*):
-            True, if the chat members are hidden.
+            True, if this chat members has been hidden.
 
         is_restricted (``bool``, *optional*):
             True, if this chat has been restricted. Supergroups, channels and bots only.
@@ -52,26 +51,17 @@ class Chat(Object):
         is_creator (``bool``, *optional*):
             True, if this chat owner is the current user. Supergroups, channels and groups only.
 
-        is_admin (``bool``, *optional*):
-            True, if the current user is admin. Supergroups, channels and groups only.
-
         is_scam (``bool``, *optional*):
             True, if this chat has been flagged for scam.
 
         is_fake (``bool``, *optional*):
             True, if this chat has been flagged for impersonation.
 
-        is_deactivated (``bool``, *optional*):
-            True, if this chat has been flagged for deactivated.
-
         is_support (``bool``):
             True, if this chat is part of the Telegram support team. Users and bots only.
 
-        is_stories_hidden (``bool``):
-            True, if this chat has hidden stories.
-
-        is_stories_unavailable (``bool``):
-            True, if this chat stories is unavailable.
+        is_forum (``bool``, *optional*):
+            True, if the supergroup chat is a forum
 
         title (``str``, *optional*):
             Title, for supergroups, channels and basic group chats.
@@ -79,8 +69,11 @@ class Chat(Object):
         username (``str``, *optional*):
             Username, for private chats, bots, supergroups and channels if available.
 
+        active_usernames (List of ``str``, *optional*):
+            If non-empty, the list of all active chat usernames; for private chats, supergroups and channels.
+
         usernames (List of :obj:`~pyrogram.types.Username`, *optional*):
-            The list of chat's collectible (and basic) usernames if available.
+            The list of chat's collectible (and basic) usernames if availables.
 
         first_name (``str``, *optional*):
             First name of the other party in a private chat, for private chats and bots.
@@ -119,6 +112,9 @@ class Chat(Object):
             Pinned message, for groups, supergroups channels and own chat.
             Returned only in :meth:`~pyrogram.Client.get_chat`.
 
+        background (:obj:`~pyrogram.types.ChatBackground`, *optional*):
+            A chat background.
+
         sticker_set_name (``str``, *optional*):
             For supergroups, name of group sticker set.
             Returned only in :meth:`~pyrogram.Client.get_chat`.
@@ -153,32 +149,6 @@ class Chat(Object):
         available_reactions (:obj:`~pyrogram.types.ChatReactions`, *optional*):
             Available reactions in the chat.
             Returned only in :meth:`~pyrogram.Client.get_chat`.
-
-        level (``int``, *optional*):
-            Channel boosts level.
-            For channel only.
-
-        reply_color (:obj:`~pyrogram.types.ChatColor`, *optional*):
-            Chat reply color.
-
-        profile_color (:obj:`~pyrogram.types.ChatColor`, *optional*):
-            Chat profile color.
-
-        personal_chat (:obj:`~pyrogram.types.Chat`, *optional*):
-            For private chats, the personal channel of the user.
-            Returned only in :meth:`~pyrogram.Client.get_chat`.
-
-        max_reaction_count (``int``):
-            The maximum number of reactions that can be set on a message in the chat
-
-        gifts_count (``int``, *optional*):
-            Number of gifts received by the user.
-
-        background_emoji_id (``int``, *optional*)
-            Chat background emoji id.
-
-        birthday (:obj:`~pyrogram.types.Birthday`, *optional*):
-            User Date of birth.
     """
 
     def __init__(
@@ -186,63 +156,54 @@ class Chat(Object):
         *,
         client: "pyrogram.Client" = None,
         id: int,
-        type: "enums.ChatType",
-        is_forum: bool = None,
-        is_verified: bool = None,
-        is_participants_hidden: bool = None,
-        is_restricted: bool = None,
-        is_creator: bool = None,
-        is_admin: bool = None,
-        is_scam: bool = None,
-        is_fake: bool = None,
-        is_deactivated: bool = None,
-        is_support: bool = None,
-        is_stories_hidden: bool = None,
-        is_stories_unavailable: bool = None,
-        title: str = None,
-        username: str = None,
-        usernames: List["types.Username"] = None,
-        first_name: str = None,
-        last_name: str = None,
-        photo: "types.ChatPhoto" = None,
-        bio: str = None,
-        description: str = None,
-        dc_id: int = None,
-        has_protected_content: bool = None,
-        invite_link: str = None,
-        pinned_message=None,
-        sticker_set_name: str = None,
-        can_set_sticker_set: bool = None,
-        members_count: int = None,
-        restrictions: List["types.Restriction"] = None,
-        permissions: "types.ChatPermissions" = None,
-        distance: int = None,
-        linked_chat: "types.Chat" = None,
-        send_as_chat: "types.Chat" = None,
-        available_reactions: Optional["types.ChatReactions"] = None,
-        reply_color: "types.ChatColor" = None,
-        profile_color: "types.ChatColor" = None,
-        personal_chat: "types.Chat" = None,
-        birthday: "types.Birthday" = None
+        type: enums.ChatType,
+        is_verified: bool | None = None,
+        is_participants_hidden: bool | None = None,
+        is_restricted: bool | None = None,
+        is_creator: bool | None = None,
+        is_scam: bool | None = None,
+        is_fake: bool | None = None,
+        is_support: bool | None = None,
+        is_forum: bool | None = None,
+        title: str | None = None,
+        username: str | None = None,
+        active_usernames: str | None = None,
+        usernames: list[types.Username] | None = None,
+        first_name: str | None = None,
+        last_name: str | None = None,
+        photo: types.ChatPhoto = None,
+        bio: str | None = None,
+        description: str | None = None,
+        dc_id: int | None = None,
+        has_protected_content: bool | None = None,
+        invite_link: str | None = None,
+        pinned_message: types.Message | None = None,
+        background: types.ChatBackground | None = None,
+        sticker_set_name: str | None = None,
+        can_set_sticker_set: bool | None = None,
+        members_count: int | None = None,
+        restrictions: list[types.Restriction] | None = None,
+        permissions: types.ChatPermissions = None,
+        distance: int | None = None,
+        linked_chat: types.Chat = None,
+        send_as_chat: types.Chat = None,
+        available_reactions: types.ChatReactions | None = None,
     ):
         super().__init__(client)
 
         self.id = id
         self.type = type
-        self.is_forum = is_forum
         self.is_verified = is_verified
         self.is_participants_hidden = is_participants_hidden
         self.is_restricted = is_restricted
         self.is_creator = is_creator
-        self.is_admin = is_admin
         self.is_scam = is_scam
         self.is_fake = is_fake
-        self.is_deactivated = is_deactivated
         self.is_support = is_support
-        self.is_stories_hidden = is_stories_hidden
-        self.is_stories_unavailable = is_stories_unavailable
+        self.is_forum = is_forum
         self.title = title
         self.username = username
+        self.active_usernames = active_usernames
         self.usernames = usernames
         self.first_name = first_name
         self.last_name = last_name
@@ -253,6 +214,7 @@ class Chat(Object):
         self.has_protected_content = has_protected_content
         self.invite_link = invite_link
         self.pinned_message = pinned_message
+        self.background = background
         self.sticker_set_name = sticker_set_name
         self.can_set_sticker_set = can_set_sticker_set
         self.members_count = members_count
@@ -262,10 +224,10 @@ class Chat(Object):
         self.linked_chat = linked_chat
         self.send_as_chat = send_as_chat
         self.available_reactions = available_reactions
-        self.personal_chat = personal_chat
-        self.reply_color = reply_color
-        self.profile_color = profile_color
-        self.birthday = birthday
+
+    @property
+    def full_name(self) -> str:
+        return " ".join(filter(None, [self.first_name, self.last_name])) or None
 
     @staticmethod
     def _parse_user_chat(client, user: raw.types.User) -> "Chat":
@@ -281,16 +243,19 @@ class Chat(Object):
             is_scam=getattr(user, "scam", None),
             is_fake=getattr(user, "fake", None),
             is_support=getattr(user, "support", None),
-            username=user.username,
+            username=user.usernames[0].username if user.usernames else user.username,
+            active_usernames=types.List([
+                username.username for username in user.usernames if username.active
+            ])
+            or None,
             usernames=types.List([types.Username._parse(r) for r in user.usernames]) or None,
             first_name=user.first_name,
             last_name=user.last_name,
             photo=types.ChatPhoto._parse(client, user.photo, peer_id, user.access_hash),
-            restrictions=types.List([types.Restriction._parse(r) for r in user.restriction_reason]) or None,
+            restrictions=types.List([types.Restriction._parse(r) for r in user.restriction_reason])
+            or None,
             dc_id=getattr(getattr(user, "photo", None), "dc_id", None),
-            reply_color=types.ChatColor._parse(getattr(user, "color", None)),
-            profile_color=types.ChatColor._parse_profile_color(getattr(user, "profile_color", None)),
-            client=client
+            client=client,
         )
 
     @staticmethod
@@ -299,22 +264,21 @@ class Chat(Object):
             return None
         peer_id = -chat.id
         usernames = getattr(chat, "usernames", [])
-        admin_rights = getattr(chat, "admin_rights", None)
+        if isinstance(chat, raw.types.ChatForbidden):
+            return Chat(id=peer_id, type=enums.ChatType.GROUP, title=chat.title, client=client)
 
         return Chat(
             id=peer_id,
             type=enums.ChatType.GROUP,
             title=chat.title,
             is_creator=getattr(chat, "creator", None),
-            is_admin=True if admin_rights else None,
-            is_deactivated=getattr(chat, "deactivated", None),
-            usernames=types.List([types.Username._parse(r) for r in usernames]) or None,
             photo=types.ChatPhoto._parse(client, getattr(chat, "photo", None), peer_id, 0),
             permissions=types.ChatPermissions._parse(getattr(chat, "default_banned_rights", None)),
             members_count=getattr(chat, "participants_count", None),
             dc_id=getattr(getattr(chat, "photo", None), "dc_id", None),
             has_protected_content=getattr(chat, "noforwards", None),
-            client=client
+            usernames=types.List([types.Username._parse(r) for r in usernames]) or None,
+            client=client,
         )
 
     @staticmethod
@@ -322,113 +286,70 @@ class Chat(Object):
         if channel is None:
             return None
         peer_id = utils.get_channel_id(channel.id)
-        restriction_reason = getattr(channel, "restriction_reason", [])
-        usernames = getattr(channel, "usernames", [])
-        admin_rights = getattr(channel, "admin_rights", None)
+        if isinstance(channel, raw.types.ChannelForbidden):
+            return Chat(
+                id=peer_id,
+                type=enums.ChatType.SUPERGROUP if channel.megagroup else enums.ChatType.CHANNEL,
+                title=channel.title,
+                client=client,
+            )
 
         return Chat(
             id=peer_id,
-            type=enums.ChatType.SUPERGROUP if getattr(channel, "megagroup", None) else enums.ChatType.CHANNEL,
-            is_forum=getattr(channel, "forum", None),
-            is_verified=getattr(channel, "verified", None),
-            is_restricted=getattr(channel, "restricted", None),
-            is_creator=getattr(channel, "creator", None),
-            is_admin=True if admin_rights else None,
-            is_scam=getattr(channel, "scam", None),
-            is_fake=getattr(channel, "fake", None),
-            is_stories_hidden=getattr(channel, "stories_hidden", None),
-            is_stories_unavailable=getattr(channel, "stories_unavailable", None),
+            type=enums.ChatType.SUPERGROUP if channel.megagroup else enums.ChatType.CHANNEL,
+            is_verified=channel.verified,
+            is_restricted=channel.restricted,
+            is_creator=channel.creator,
+            is_scam=channel.scam,
+            is_fake=channel.fake,
+            is_forum=channel.forum,
             title=channel.title,
-            username=getattr(channel, "username", None),
-            usernames=types.List([types.Username._parse(r) for r in usernames]) or None,
-            photo=types.ChatPhoto._parse(client, getattr(channel, "photo", None), peer_id,
-                                         getattr(channel, "access_hash", 0)),
-            restrictions=types.List([types.Restriction._parse(r) for r in restriction_reason]) or None,
-            permissions=types.ChatPermissions._parse(getattr(channel, "default_banned_rights", None)),
-            members_count=getattr(channel, "participants_count", None),
-            dc_id=getattr(getattr(channel, "photo", None), "dc_id", None),
-            has_protected_content=getattr(channel, "noforwards", None),
-            reply_color=types.ChatColor._parse(getattr(channel, "color", None)),
-            client=client
+            username=channel.username,
+            photo=types.ChatPhoto._parse(client, channel.photo, peer_id, channel.access_hash),
+            restrictions=types.List([
+                types.Restriction._parse(r) for r in channel.restriction_reason
+            ])
+            or None,
+            permissions=types.ChatPermissions._parse(channel.default_banned_rights),
+            members_count=channel.participants_count,
+            dc_id=getattr(channel.photo, "dc_id", None),
+            has_protected_content=channel.noforwards,
+            usernames=types.List([types.Username._parse(r) for r in channel.usernames]) or None,
+            client=client,
         )
 
     @staticmethod
     def _parse(
         client,
-        message: Union[raw.types.Message, raw.types.MessageService],
+        message: raw.types.Message | raw.types.MessageService,
         users: dict,
         chats: dict,
-        is_chat: bool
-    ) -> "Chat":
+        is_chat: bool,
+    ) -> Chat:
         from_id = utils.get_raw_peer_id(message.from_id)
         peer_id = utils.get_raw_peer_id(message.peer_id)
         chat_id = (peer_id or from_id) if is_chat else (from_id or peer_id)
 
         if isinstance(message.peer_id, raw.types.PeerUser):
-            return Chat._parse_user_chat(client, users.get(chat_id))
+            return Chat._parse_user_chat(client, users[chat_id])
 
-        elif isinstance(message.peer_id, raw.types.PeerChat):
-            return Chat._parse_chat_chat(client, chats.get(chat_id))
-        else:
-            return Chat._parse_channel_chat(client, chats.get(chat_id))
-        
-    @staticmethod
-    async def _parse_with_fallback(
-        client,
-        message: Union[raw.types.Message, raw.types.MessageService],
-        users: dict,
-        chats: dict,
-        is_chat: bool
-    ) -> "Chat":
-        from_id = utils.get_raw_peer_id(message.from_id)
-        peer_id = utils.get_raw_peer_id(message.peer_id)
-        chat_id = (peer_id or from_id) if is_chat else (from_id or peer_id)
-
-        if isinstance(message.peer_id, raw.types.PeerUser):
-            user_data = users.get(chat_id)
-            if not user_data:
-                try:
-                    chat_obj = await client.get_chat(chat_id)
-                    users[chat_obj.id] = chat_obj
-                    user_data = users.get(chat_id)
-                except Exception:
-                    return None
-            return Chat._parse_user_chat(client, user_data)
-
-        elif isinstance(message.peer_id, raw.types.PeerChat):
-            chat_data = chats.get(chat_id)
-            if not chat_data:
-                try:
-                    chat_obj = await client.get_chat(chat_id)
-                    chats[chat_obj.id] = chat_obj
-                    chat_data = chats.get(chat_id)
-                except Exception:
-                    return None
-            return Chat._parse_chat_chat(client, chat_data)
-
-        else:
-            channel_data = chats.get(chat_id)
-            if not channel_data:
-                try:
-                    chat_obj = await client.get_chat(chat_id)
-                    chats[chat_obj.id] = chat_obj
-                    channel_data = chats.get(chat_id)
-                except Exception:
-                    return None
-            return Chat._parse_channel_chat(client, channel_data)
+        if isinstance(message.peer_id, raw.types.PeerChat):
+            return Chat._parse_chat_chat(client, chats[chat_id])
 
+        return Chat._parse_channel_chat(client, chats[chat_id])
 
     @staticmethod
     def _parse_dialog(client, peer, users: dict, chats: dict):
         if isinstance(peer, raw.types.PeerUser):
             return Chat._parse_user_chat(client, users[peer.user_id])
-        elif isinstance(peer, raw.types.PeerChat):
+        if isinstance(peer, raw.types.PeerChat):
             return Chat._parse_chat_chat(client, chats[peer.chat_id])
-        else:
-            return Chat._parse_channel_chat(client, chats[peer.channel_id])
+        return Chat._parse_channel_chat(client, chats[peer.channel_id])
 
     @staticmethod
-    async def _parse_full(client, chat_full: Union[raw.types.messages.ChatFull, raw.types.users.UserFull]) -> "Chat":
+    async def _parse_full(
+        client, chat_full: raw.types.messages.ChatFull | raw.types.users.UserFull
+    ) -> Chat:
         users = {u.id: u for u in chat_full.users}
         chats = {c.id: c for c in chat_full.chats}
 
@@ -440,36 +361,33 @@ class Chat(Object):
 
             if full_user.pinned_msg_id:
                 parsed_chat.pinned_message = await client.get_messages(
-                    parsed_chat.id,
-                    message_ids=full_user.pinned_msg_id
+                    parsed_chat.id, message_ids=full_user.pinned_msg_id
                 )
+
+            if getattr(full_user, "wallpaper", None):
+                parsed_chat.background = types.ChatBackground._parse(client, full_user.wallpaper)
         else:
             full_chat = chat_full.full_chat
             chat_raw = chats[full_chat.id]
 
             if isinstance(full_chat, raw.types.ChatFull):
                 parsed_chat = Chat._parse_chat_chat(client, chat_raw)
-                parsed_chat.description = full_chat.about or None
-
                 if isinstance(full_chat.participants, raw.types.ChatParticipants):
                     parsed_chat.members_count = len(full_chat.participants.participants)
             else:
                 parsed_chat = Chat._parse_channel_chat(client, chat_raw)
                 parsed_chat.members_count = full_chat.participants_count
-                parsed_chat.description = full_chat.about or None
                 # TODO: Add StickerSet type
                 parsed_chat.can_set_sticker_set = full_chat.can_set_stickers
                 parsed_chat.sticker_set_name = getattr(full_chat.stickerset, "short_name", None)
-                parsed_chat.is_participants_hidden = full_chat.participants_hidden
+                parsed_chat.is_participants_hidden = getattr(
+                    full_chat, "participants_hidden", False
+                )
 
-                linked_chat_raw = chats.get(full_chat.linked_chat_id, None)
-
-                if linked_chat_raw:
+                if linked_chat_raw := chats.get(full_chat.linked_chat_id):
                     parsed_chat.linked_chat = Chat._parse_channel_chat(client, linked_chat_raw)
 
-                default_send_as = full_chat.default_send_as
-
-                if default_send_as:
+                if default_send_as := full_chat.default_send_as:
                     if isinstance(default_send_as, raw.types.PeerUser):
                         send_as_raw = users[default_send_as.user_id]
                     else:
@@ -477,31 +395,213 @@ class Chat(Object):
 
                     parsed_chat.send_as_chat = Chat._parse_chat(client, send_as_raw)
 
+            if getattr(full_chat, "wallpaper", None):
+                parsed_chat.background = types.ChatBackground._parse(client, full_chat.wallpaper)
+
+            parsed_chat.description = full_chat.about or None
+
             if full_chat.pinned_msg_id:
                 parsed_chat.pinned_message = await client.get_messages(
-                    parsed_chat.id,
-                    message_ids=full_chat.pinned_msg_id
+                    parsed_chat.id, message_ids=full_chat.pinned_msg_id
                 )
 
             if isinstance(full_chat.exported_invite, raw.types.ChatInviteExported):
                 parsed_chat.invite_link = full_chat.exported_invite.link
 
-            parsed_chat.available_reactions = types.ChatReactions._parse(client, full_chat.available_reactions)
+            parsed_chat.available_reactions = types.ChatReactions._parse(
+                client, full_chat.available_reactions
+            )
 
         return parsed_chat
 
     @staticmethod
-    def _parse_chat(client, chat: Union[raw.types.Chat, raw.types.User, raw.types.Channel]) -> "Chat":
+    def _parse_chat(client, chat: raw.types.Chat | raw.types.User | raw.types.Channel) -> Chat:
         if isinstance(chat, raw.types.Chat):
             return Chat._parse_chat_chat(client, chat)
-        elif isinstance(chat, raw.types.User):
+        if isinstance(chat, raw.types.User):
             return Chat._parse_user_chat(client, chat)
-        else:
-            return Chat._parse_channel_chat(client, chat)
+        return Chat._parse_channel_chat(client, chat)
+    
+    def listen(
+        self,
+        filters: filters.Filter | None = None,
+        listener_type: ListenerTypes = ListenerTypes.MESSAGE,
+        timeout: int | None = None,
+        unallowed_click_alert: bool = True,
+        user_id: int | str | list[int | str] | None = None,
+        message_id: int | list[int] | None = None,
+        inline_message_id: str | list[str] | None = None,
+    ):
+        """
+        Bound method *listen* of :obj:`~pyrogram.types.Chat`.
 
-    @property
-    def full_name(self) -> str:
-        return " ".join(filter(None, [self.first_name, self.last_name])) or None
+        Use as a shortcut for:
+
+        .. code-block:: python
+
+            await client.listen(chat_id=chat_id)
+
+        Example:
+            .. code-block:: python
+
+                await chat.listen()
+
+        Parameters:
+            filters (``Optional[filters.Filter]``):
+                A filter to check if the listener should be fulfilled.
+
+            listener_type (``ListenerTypes``):
+                The type of listener to create. Defaults to :attr:`pyrogram.types.ListenerTypes.MESSAGE`.
+
+            timeout (``Optional[int]``):
+                The maximum amount of time to wait for the listener to be fulfilled. Defaults to ``None``.
+
+            unallowed_click_alert (``bool``):
+                Whether to alert the user if they click on a button that is not intended for them. Defaults to ``True``.
+
+            user_id (``Optional[Union[int, str], List[Union[int, str]]]``):
+                The user ID(s) to listen for. Defaults to ``None``.
+
+            message_id (``Optional[Union[int, List[int]]]``):
+                The message ID(s) to listen for. Defaults to ``None``.
+
+            inline_message_id (``Optional[Union[str, List[str]]]``):
+                The inline message ID(s) to listen for. Defaults to ``None``.
+
+        Returns:
+            Union[:obj:`~pyrogram.types.Message`, :obj:`~pyrogram.types.CallbackQuery`]: The Message or CallbackQuery
+        """
+        return self._client.listen(
+            chat_id=self.id,
+            filters=filters,
+            listener_type=listener_type,
+            timeout=timeout,
+            unallowed_click_alert=unallowed_click_alert,
+            user_id=user_id,
+            message_id=message_id,
+            inline_message_id=inline_message_id,
+        )
+
+    def ask(
+        self,
+        text: str,
+        filters: filters.Filter | None = None,
+        listener_type: ListenerTypes = ListenerTypes.MESSAGE,
+        timeout: int | None = None,
+        unallowed_click_alert: bool = True,
+        user_id: int | str | list[int | str] | None = None,
+        message_id: int | list[int] | None = None,
+        inline_message_id: str | list[str] | None = None,
+        *args,
+        **kwargs,
+    ):
+        """
+        Bound method *ask* of :obj:`~pyrogram.types.Chat`.
+
+        Use as a shortcut for:
+
+        .. code-block:: python
+
+            await client.ask(chat_id=chat_id, text=text)
+
+        Example:
+
+            .. code-block:: python
+
+                await chat.ask("What's your name?")
+
+        Parameters:
+            text (``str``):
+                The text to send.
+
+            filters (``Optional[filters.Filter]``):
+                Same as :meth:`pyrogram.Client.listen`.
+
+            listener_type (``ListenerTypes``):
+                Same as :meth:`pyrogram.Client.listen`.
+
+            timeout (``Optional[int]``):
+                Same as :meth:`pyrogram.Client.listen`.
+
+            unallowed_click_alert (``bool``):
+                Same as :meth:`pyrogram.Client.listen`.
+
+            user_id (``Optional[Union[int, str], List[Union[int, str]]]``):
+                The user ID(s) to listen for. Defaults to ``None``.
+
+            message_id (``Optional[Union[int, List[int]]]``):
+                The message ID(s) to listen for. Defaults to ``None``.
+
+            inline_message_id (``Optional[Union[str, List[str]]]``):
+                The inline message ID(s) to listen for. Defaults to ``None``.
+
+            args (``Any``):
+                Additional arguments to pass to :meth:`pyrogram.Client.send_message`.
+
+            kwargs (``Any``):
+                Additional keyword arguments to pass to :meth:`pyrogram.Client.send_message`.
+
+        Returns:
+            Union[:obj:`~pyrogram.types.Message`, :obj:`~pyrogram.types.CallbackQuery`]: The Message or CallbackQuery
+        """
+        return self._client.ask(
+            chat_id=self.id,
+            text=text,
+            filters=filters,
+            listener_type=listener_type,
+            timeout=timeout,
+            unallowed_click_alert=unallowed_click_alert,
+            user_id=user_id,
+            message_id=message_id,
+            inline_message_id=inline_message_id,
+            *args,
+            **kwargs,
+        )
+
+    def stop_listening(
+        self,
+        listener_type: ListenerTypes = ListenerTypes.MESSAGE,
+        user_id: int | str | list[int | str] | None = None,
+        message_id: int | list[int] | None = None,
+        inline_message_id: str | list[str] | None = None,
+    ):
+        """
+        Bound method *stop_listening* of :obj:`~pyrogram.types.Chat`.
+
+        Use as a shortcut for:
+
+        .. code-block:: python
+
+            await client.stop_listening(chat_id=chat_id)
+
+        Example:
+            .. code-block:: python
+
+                await chat.stop_listening()
+
+        Parameters:
+            listener_type (``ListenerTypes``):
+                The type of listener to stop listening for. Defaults to :attr:`pyrogram.types.ListenerTypes.MESSAGE`.
+
+            user_id (``Optional[Union[int, str], List[Union[int, str]]]``):
+                The user ID(s) to stop listening for. Defaults to ``None``.
+
+            message_id (``Optional[Union[int, List[int]]]``):
+                The message ID(s) to stop listening for. Defaults to ``None``.
+
+            inline_message_id (``Optional[Union[str, List[str]]]``):
+                The inline message ID(s) to stop listening for. Defaults to ``None``.
+
+        Returns:
+            ``bool``: The return value of :meth:`pyrogram.Client.stop_listening`.
+        """
+        return self._client.stop_listening(
+            chat_id=self.id,
+            listener_type=listener_type,
+            user_id=user_id,
+            message_id=message_id,
+            inline_message_id=inline_message_id,
+        )
 
     async def archive(self):
         """Bound method *archive* of :obj:`~pyrogram.types.Chat`.
