@@ -16,16 +16,17 @@
 #  You should have received a copy of the GNU Lesser General Public License
 #  along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.
 
+
+from __future__ import annotations
+
 import html
 from datetime import datetime
-from typing import List, Optional
 
 import pyrogram
-from pyrogram import enums, utils
-from pyrogram import raw
-from pyrogram import types
-from ..object import Object
-from ..update import Update
+from pyrogram import enums, raw, types, utils, filters
+from pyrogram.types.object import Object
+from pyrogram.types.update import Update
+from pyrogram.types.pyromod import ListenerTypes
 
 
 class Link(str):
@@ -100,15 +101,6 @@ class User(Object, Update):
         is_premium (``bool``, *optional*):
             True, if this user is a premium user.
 
-        is_close_friend (``bool``):
-            True, if this user is a close friend.
-
-        is_stories_hidden (``bool``):
-            True, if this user has hidden stories.
-
-        is_stories_unavailable (``bool``):
-            True, if this chat stories is unavailable.
-
         first_name (``str``, *optional*):
             User's or bot's first name.
 
@@ -116,7 +108,7 @@ class User(Object, Update):
             User's or bot's last name.
 
         full_name (``str``, *property*):
-            Full name of the other party in a private chat, for private chats and bots.
+            Full name of the other party in a private chat.
 
         status (:obj:`~pyrogram.enums.UserStatus`, *optional*):
             User's last seen & online status. ``None``, for bots.
@@ -130,8 +122,11 @@ class User(Object, Update):
         username (``str``, *optional*):
             User's or bot's username.
 
+        active_usernames (List of ``str``, *optional*):
+            If non-empty, the list of all active chat usernames; for private chats, supergroups and channels.
+
         usernames (List of :obj:`~pyrogram.types.Username`, *optional*):
-            The list of user's collectible (and basic) usernames if available.
+            The list of user's collectible (and basic) usernames if availables.
 
         language_code (``str``, *optional*):
             IETF language tag of the user's language.
@@ -159,51 +154,39 @@ class User(Object, Update):
             Generate a text mention for this user.
             You can use ``user.mention()`` to mention the user using their first name (styled using html), or
             ``user.mention("another name")`` for a custom name. To choose a different style
-            ("html" or "md"/"markdown") use ``user.mention(style="md")``.
-
-        color (``int``, *optional*)
-            Chat color.
-
-        background_emoji_id (``int``, *optional*)
-            Chat background emoji id.
+            ("HTML" or "MARKDOWN") use ``user.mention(style=ParseMode.MARKDOWN)``.
     """
 
     def __init__(
         self,
         *,
-        client: "pyrogram.Client" = None,
+        client: pyrogram.Client = None,
         id: int,
-        is_self: bool = None,
-        is_contact: bool = None,
-        is_mutual_contact: bool = None,
-        is_deleted: bool = None,
-        is_frozen: bool = None,
-        is_bot: bool = None,
-        is_verified: bool = None,
-        is_restricted: bool = None,
-        is_scam: bool = None,
-        is_fake: bool = None,
-        is_support: bool = None,
-        is_contacts_only: bool = None,
-        is_premium: bool = None,
-        first_name: str = None,
-        last_name: str = None,
-        status: "enums.UserStatus" = None,
-        last_online_date: datetime = None,
-        next_offline_date: datetime = None,
-        username: str = None,
-        usernames: List["types.Username"] = None,
-        language_code: str = None,
-        emoji_status: Optional["types.EmojiStatus"] = None,
-        dc_id: int = None,
-        phone_number: str = None,
-        photo: "types.ChatPhoto" = None,
-        restrictions: List["types.Restriction"] = None,
-        reply_color: "types.ChatColor" = None,
-        profile_color: "types.ChatColor" = None,
-        active_users: int = None,
-        frozen_icon: int = None
-        
+        is_self: bool | None = None,
+        is_contact: bool | None = None,
+        is_mutual_contact: bool | None = None,
+        is_deleted: bool | None = None,
+        is_bot: bool | None = None,
+        is_verified: bool | None = None,
+        is_restricted: bool | None = None,
+        is_scam: bool | None = None,
+        is_fake: bool | None = None,
+        is_support: bool | None = None,
+        is_premium: bool | None = None,
+        first_name: str | None = None,
+        last_name: str | None = None,
+        status: enums.UserStatus = None,
+        last_online_date: datetime | None = None,
+        next_offline_date: datetime | None = None,
+        username: str | None = None,
+        active_usernames: str | None = None,
+        usernames: list[types.Username] | None = None,
+        language_code: str | None = None,
+        emoji_status: types.EmojiStatus | None = None,
+        dc_id: int | None = None,
+        phone_number: str | None = None,
+        photo: types.ChatPhoto = None,
+        restrictions: list[types.Restriction] | None = None,
     ):
         super().__init__(client)
 
@@ -212,7 +195,6 @@ class User(Object, Update):
         self.is_contact = is_contact
         self.is_mutual_contact = is_mutual_contact
         self.is_deleted = is_deleted
-        self.is_frozen = is_frozen
         self.is_bot = is_bot
         self.is_verified = is_verified
         self.is_restricted = is_restricted
@@ -220,13 +202,13 @@ class User(Object, Update):
         self.is_fake = is_fake
         self.is_support = is_support
         self.is_premium = is_premium
-        self.is_contacts_only = is_contacts_only
         self.first_name = first_name
         self.last_name = last_name
         self.status = status
         self.last_online_date = last_online_date
         self.next_offline_date = next_offline_date
         self.username = username
+        self.active_usernames = active_usernames
         self.usernames = usernames
         self.language_code = language_code
         self.emoji_status = emoji_status
@@ -234,10 +216,6 @@ class User(Object, Update):
         self.phone_number = phone_number
         self.photo = photo
         self.restrictions = restrictions
-        self.reply_color = reply_color
-        self.profile_color = profile_color
-        self.active_users = active_users
-        self.frozen_icon = frozen_icon
 
     @property
     def full_name(self) -> str:
@@ -252,25 +230,9 @@ class User(Object, Update):
         )
 
     @staticmethod
-    def _parse(client, user: "raw.base.User") -> Optional["User"]:
+    def _parse(client, user: raw.base.User) -> User | None:
         if user is None or isinstance(user, raw.types.UserEmpty):
             return None
-        user_name = user.username
-        active_usernames = getattr(user, "usernames", [])
-        active_users = getattr(user, "bot_active_users", None)
-        usernames = None
-        if len(active_usernames) >= 1:
-            usernames = []
-            for username in active_usernames:
-                if username.editable:
-                    user_name = username.username
-                else:
-                    usernames.append(types.Username._parse(username))
-        if user_name is None and usernames is not None and len(usernames) > 0:
-            user_name = usernames[0].username
-            usernames.pop(0)
-        
-        frozen_icon = getattr(user, "bot_verification_icon", None)
 
         return User(
             id=user.id,
@@ -278,7 +240,6 @@ class User(Object, Update):
             is_contact=user.contact,
             is_mutual_contact=user.mutual_contact,
             is_deleted=user.deleted,
-            is_frozen=True if frozen_icon else False,
             is_bot=user.bot,
             is_verified=user.verified,
             is_restricted=user.restricted,
@@ -286,27 +247,27 @@ class User(Object, Update):
             is_fake=user.fake,
             is_support=user.support,
             is_premium=user.premium,
-            is_contacts_only=user.contact_require_premium,
             first_name=user.first_name,
             last_name=user.last_name,
             **User._parse_status(user.status, user.bot),
-            username=user_name,
-            usernames=usernames,
+            username=user.usernames[0].username if user.usernames else user.username,
+            active_usernames=types.List([
+                username.username for username in user.usernames if username.active
+            ])
+            or None,
+            usernames=types.List([types.Username._parse(r) for r in user.usernames]) or None,
             language_code=user.lang_code,
             emoji_status=types.EmojiStatus._parse(client, user.emoji_status),
             dc_id=getattr(user.photo, "dc_id", None),
             phone_number=user.phone,
             photo=types.ChatPhoto._parse(client, user.photo, user.id, user.access_hash),
-            restrictions=types.List([types.Restriction._parse(r) for r in user.restriction_reason]) or None,
-            reply_color=types.ChatColor._parse(getattr(user, "color", None)),
-            profile_color=types.ChatColor._parse_profile_color(getattr(user, "profile_color", None)),
-            active_users=active_users,
-            frozen_icon=frozen_icon,
-            client=client
+            restrictions=types.List([types.Restriction._parse(r) for r in user.restriction_reason])
+            or None,
+            client=client,
         )
 
     @staticmethod
-    def _parse_status(user_status: "raw.base.UserStatus", is_bot: bool = False):
+    def _parse_status(user_status: raw.base.UserStatus, is_bot: bool = False):
         if isinstance(user_status, raw.types.UserStatusOnline):
             status, date = enums.UserStatus.ONLINE, user_status.expires
         elif isinstance(user_status, raw.types.UserStatusOffline):
@@ -335,15 +296,180 @@ class User(Object, Update):
         return {
             "status": status,
             "last_online_date": last_online_date,
-            "next_offline_date": next_offline_date
+            "next_offline_date": next_offline_date,
         }
 
     @staticmethod
-    def _parse_user_status(client, user_status: "raw.types.UpdateUserStatus"):
+    def _parse_user_status(client, user_status: raw.types.UpdateUserStatus):
         return User(
             id=user_status.user_id,
             **User._parse_status(user_status.status),
-            client=client
+            client=client,
+        )
+    
+    def listen(
+        self,
+        filters: filters.Filter | None = None,
+        listener_type: ListenerTypes = ListenerTypes.MESSAGE,
+        timeout: int | None = None,
+        unallowed_click_alert: bool = True,
+        chat_id: int | str | list[int | str] | None = None,
+        message_id: int | list[int] | None = None,
+        inline_message_id: str | list[str] | None = None,
+    ):
+        """
+        Bound method *listen* of :obj:`~pyrogram.types.User`.
+
+        Use as a shortcut for:
+
+        .. code-block:: python
+
+            client.listen(user_id=user.id)
+
+        Example:
+            .. code-block:: python
+
+                user.listen()
+
+        Parameters:
+            filters (``Optional[pyrogram.Filter]``):
+                Same as :meth:`pyrogram.Client.listen`.
+
+            listener_type (``ListenerTypes``):
+                Same as :meth:`pyrogram.Client.listen`.
+
+            timeout (``Optional[int]``):
+                Same as :meth:`pyrogram.Client.listen`.
+
+            unallowed_click_alert (``bool``):
+                Same as :meth:`pyrogram.Client.listen`.
+
+            chat_id (``Union[int, str], List[Union[int, str]]``):
+                Same as :meth:`pyrogram.Client.listen`.
+
+            message_id (``Union[int, List[int]]``):
+                Same as :meth:`pyrogram.Client.listen`.
+
+            inline_message_id (``Union[str, List[str]]``):
+                Same as :meth:`pyrogram.Client.listen`.
+
+        Returns:
+            ``Union[Message, CallbackQuery]``: The Message or CallbackQuery that fulfilled the listener.
+        """
+        return self._client.listen(
+            user_id=self.id,
+            filters=filters,
+            listener_type=listener_type,
+            timeout=timeout,
+            unallowed_click_alert=unallowed_click_alert,
+            chat_id=chat_id,
+            message_id=message_id,
+            inline_message_id=inline_message_id,
+        )
+
+    def ask(
+        self,
+        text: str,
+        filters: filters.Filter | None = None,
+        listener_type: ListenerTypes = ListenerTypes.MESSAGE,
+        timeout: int | None = None,
+        unallowed_click_alert: bool = True,
+        message_id: int | list[int] | None = None,
+        inline_message_id: str | list[str] | None = None,
+        *args,
+        **kwargs,
+    ):
+        """
+        Bound method *ask* of :obj:`~pyrogram.types.User`.
+
+        Use as a shortcut for:
+
+        .. code-block:: python
+
+            client.ask(user_id=user.id)
+
+        Example:
+            .. code-block:: python
+
+                user.ask("Hello!")
+
+        Parameters:
+            text (``str``):
+                Same as :meth:`pyrogram.Client.ask`.
+
+            filters (``Optional[pyrogram.Filter]``):
+                Same as :meth:`pyrogram.Client.ask`.
+
+            listener_type (``ListenerTypes``):
+                Same as :meth:`pyrogram.Client.ask`.
+
+            timeout (``Optional[int]``):
+                Same as :meth:`pyrogram.Client.ask`.
+
+            unallowed_click_alert (``bool``):
+                Same as :meth:`pyrogram.Client.ask`.
+
+            message_id (``Union[int, List[int]]``):
+                Same as :meth:`pyrogram.Client.ask`.
+
+            inline_message_id (``Union[str, List[str]]``):
+                Same as :meth:`pyrogram.Client.ask`.
+
+            args (``Any``):
+                Same as :meth:`pyrogram.Client.ask`.
+
+            kwargs (``Any``):
+                Same as :meth:`pyrogram.Client.ask`.
+
+        Returns:
+            ``Union[Message, CallbackQuery]``: The Message or CallbackQuery that fulfilled the listener.
+        """
+        return self._client.ask(
+            chat_id=self.id,
+            text=text,
+            user_id=self.id,
+            filters=filters,
+            listener_type=listener_type,
+            timeout=timeout,
+            unallowed_click_alert=unallowed_click_alert,
+            message_id=message_id,
+            inline_message_id=inline_message_id,
+            *args,
+            **kwargs,
+        )
+
+    def stop_listening(
+        self,
+        listener_type: ListenerTypes = ListenerTypes.MESSAGE,
+        chat_id: int | str | list[int | str] | None = None,
+        message_id: int | list[int] | None = None,
+        inline_message_id: str | list[str] | None = None,
+    ):
+        """
+        Stops listening for messages from the user. Calls Client.stop_listening() with the user_id set to the user's id.
+
+        Parameters:
+            listener_type (``ListenerTypes``):
+                Same as :meth:`pyrogram.Client.stop_listening`.
+
+            chat_id (``Union[int, str], List[Union[int, str]]``):
+                Same as :meth:`pyrogram.Client.stop_listening`.
+
+            message_id (``Union[int, List[int]]``):
+                Same as :meth:`pyrogram.Client.stop_listening`.
+
+            inline_message_id (``Union[str, List[str]]``):
+                Same as :meth:`pyrogram.Client.stop_listening`.
+
+        Returns:
+            ``None``
+        """
+        return self._client.stop_listening(
+            user_id=self.id,
+            listener_type=listener_type,
+            chat_id=chat_id,
+            message_id=message_id,
+            inline_message_id=inline_message_id,
         )
 
     async def archive(self):
